@@ -44,8 +44,8 @@ try: import pika
 except: pika = None
 
 URL = "amqp://guest:guest@localhost"
-""" The default url to be used for the connection when
-no other url is provided (used most of the times) """
+""" The default URL to be used for the connection when
+no other URL is provided (used most of the times) """
 
 TIMEOUT = 100
 """ The time the retrieval of a connection waits before
@@ -53,7 +53,7 @@ returning this avoid possible problems with the current
 implementation of the blocking client """
 
 connection = None
-""" The global wide connection to the amqp server
+""" The global wide connection to the AMQP server
 that is meant to be used across sessions """
 
 class AMQP(object):
@@ -71,7 +71,7 @@ class AMQP(object):
         url_p = legacy.urlparse(url)
         parameters = pika.ConnectionParameters(
             host = url_p.hostname,
-            virtual_host = url_p.path[1:],
+            virtual_host = url_p.path or "/",
             credentials = pika.PlainCredentials(url_p.username, url_p.password)
         )
         parameters.socket_timeout = timeout
@@ -87,7 +87,7 @@ def get_connection(url = URL, timeout = TIMEOUT):
     url_p = legacy.urlparse(url)
     parameters = pika.ConnectionParameters(
         host = url_p.hostname,
-        virtual_host = url_p.path[1:],
+        virtual_host = url_p.path or "/",
         credentials = pika.PlainCredentials(url_p.username, url_p.password)
     )
     parameters.socket_timeout = timeout
