@@ -62,6 +62,9 @@ class DataAdapter(object):
     def name_g(cls):
         return cls.__name__[:-7].lower()
 
+    def encoder(self):
+        return None
+
     def collection(self, name, *args, **kwargs):
         raise exceptions.NotImplementedError()
 
@@ -110,6 +113,9 @@ class DataAdapter(object):
 
 class MongoAdapter(DataAdapter):
 
+    def encoder(self):
+        return mongo.MongoEncoder
+
     def collection(self, name, *args, **kwargs):
         db = self.get_db()
         collection = db[name]
