@@ -67,6 +67,16 @@ class Part(object):
         if name.endswith("_part"): name = name[:-5]
         return name
 
+    def version(self):
+        return None
+
+    def info(self):
+        return dict(
+            name = self.name(),
+            version = self.version(),
+            class_name = self.class_name()
+        )
+
     def class_name(self):
         cls = self.__class__
         if not self.__module__: return cls.__name__
