@@ -97,7 +97,7 @@ with the official descriptive message for it """
 class Request(object):
     """
     Request class that acts as a proxy for the both
-    the input and output of an http request.
+    the input and output of an HTTP request.
 
     Other responsibilities should include indirect
     session management and serialization.
@@ -527,7 +527,7 @@ class Request(object):
         else: self.locale = fallback
 
     def get_locale(self, fallback = "en_us"):
-        # tries to retrieve the locale value from the provided url
+        # tries to retrieve the locale value from the provided URL
         # parameters (this is the highest priority) and in case it
         # exists returns this locale immediately
         locale = self.params.get("locale", None)
@@ -563,7 +563,7 @@ class Request(object):
         # starts the list that is going to be used to store the various
         # languages "recovered" from the accept language header, note that
         # the order of these languages should be from the most relevant to
-        # the least relevant as defined in http specification
+        # the least relevant as defined in HTTP specification
         langs = []
 
         # splits the accept language header into the various components of
@@ -640,6 +640,13 @@ class Request(object):
         return set_cookie
 
     def get_headers(self):
+        return self.get_out_headers()
+
+    def get_in_headers(self):
+        headers = self.in_headers.items()
+        return legacy.eager(headers)
+
+    def get_out_headers(self):
         headers = self.out_headers.items()
         return legacy.eager(headers)
 
