@@ -74,3 +74,41 @@ class OrderedDict(list):
     def set(self, key, value, append = False):
         if key in self and not append: self.item(key)[1] = value
         else: self[key] = value
+
+class LazyDict(dict):
+
+    def __getitem__(self, key, force = False, resolve = False):
+        value = dict.__getitem__(self, key)
+        if force: return value
+        if not isinstance(value, LazyValue): return value
+        return value.resolve(force = resolve)
+
+    def resolve(self, force = False):
+        result = dict()
+        for key in self:
+            value = self.__getitem__(key, resolve = force)
+            result[key] = value
+        return result
+
+    def to_dict(self, force = True):
+        return self.resolve(force = force)
+
+class LazyValue(object):
+
+    def __init__(self, callable):
+        self.callable = callable
+
+    def __call__(self):
+        return self.call()
+
+    def resolve(self, force = False):
+        if hasattr(self, "_value") and not force:
+            return self._value
+        self._value = self.callable()
+        return self._value
+
+    def call(self):
+        return self.resolve()
+
+lazy_dict = LazyDict
+lazy = LazyValue
